#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.Indicators;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

//This namespace holds Strategies in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Strategies.GomPro
{
	public class GomOFDeltaSampleStrat : Strategy
	{
		private  Indicators.GomPro.GomOrderFlowProValues GomOrderFlowProValues1;

		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description									= @"Enters long  when delta > minabsdelta , short when delta < -minabsdelta ";
				Name										= "GomOFDeltaSampleStrat";
				Calculate									= Calculate.OnBarClose;
				EntriesPerDirection							= 1;
				EntryHandling								= EntryHandling.UniqueEntries;
				IsExitOnSessionCloseStrategy				= true;
				ExitOnSessionCloseSeconds					= 30;
				IsFillLimitOnTouch							= false;
				MaximumBarsLookBack							= MaximumBarsLookBack.TwoHundredFiftySix;
				OrderFillResolution							= OrderFillResolution.Standard;
				Slippage									= 0;
				StartBehavior								= StartBehavior.WaitUntilFlat;
				TimeInForce									= TimeInForce.Gtc;
				TraceOrders									= false;
				RealtimeErrorHandling						= RealtimeErrorHandling.StopCancelClose;
				StopTargetHandling							= StopTargetHandling.PerEntryExecution;
				BarsRequiredToTrade							= 20;
				// Disable this property for performance gains in Strategy Analyzer optimizations
				// See the Help Guide for additional information
				IsInstantiatedOnEachOptimizationIteration	= true;
				MinAbsDelta					= 500;
				Target					= 10;
				Stop					= 10;
			}
			else if (State == State.Configure)
			{
				SetProfitTarget("", CalculationMode.Ticks, Target);
				SetStopLoss("", CalculationMode.Ticks, Stop, false);
			}
			else if (State == State.DataLoaded)
			{				
				// you can use the ninja strategy builder to get the correct initializer
				// here are the enums:
				
				// public enum DeltaCalcType {BidAsk,UpDownTick};
				// public enum ImbalanceDirectionType {Diagonal,Horizontal,None};
				// public enum ImbalanceComparisonType { Ratio, Difference };
				// public enum ReversalPocPositionType { Anywhere, InDecliningSideHalfOfBar, InDecliningSideThirdOfBar, InDecliningZone };
				
				 GomOrderFlowProValues1	= GomOrderFlowProValues(Close,Gom.DeltaLib.DeltaCalcType.BidAsk,false,-1, 0, 1, 
										Gom.OrderFlow.ImbalanceDirectionType.Diagonal, Gom.OrderFlow.ImbalanceComparisonType.Ratio, 3, 
										Gom.OrderFlow.ImbalanceDirectionType.None, Gom.OrderFlow.ImbalanceComparisonType.Ratio, 3,0,1,-1, 3, 0, 3, false, 1, 
										Gom.OrderFlow.ReversalPocPositionType.Anywhere, true,false );
				
			}
		}

		

		protected override void OnBarUpdate()
		{
			if (CurrentBar < 1)
			return;

			if (GomOrderFlowProValues1.Delta[0] >= MinAbsDelta)
			{
				EnterLong(Convert.ToInt32(DefaultQuantity), "");
			}
			

			if (GomOrderFlowProValues1.Delta[0] <= -MinAbsDelta)
			{
				EnterShort(Convert.ToInt32(DefaultQuantity), "");
			}
			
			
			
		}

		#region Properties
		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="MinAbsDelta", Order=1, GroupName="Parameters")]
		public int MinAbsDelta
		{ get; set; }

		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="Target", Order=2, GroupName="Parameters")]
		public int Target
		{ get; set; }

		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="Stop", Order=3, GroupName="Parameters")]
		public int Stop
		{ get; set; }
		#endregion

	}
}
